.. django-modeltranslation documentation master file

.. _ref-topics-modeltranslation:

.. include:: readme.rst


Table of Contents
=================

.. toctree::
   :maxdepth: 2

   installation
   registration
   usage
   forms
   admin
   commands
   caveats

.. toctree::
   :maxdepth: 1

   contribute
   related_projects
   changelog

.. include:: authors.rst
